@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Error;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Error::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.34.0');
+use version 0.77; our $VERSION = qv('v0.34.2');
 
 use Moose;
 use Carp qw( cluck );
@@ -115,27 +115,17 @@ Spreadsheet::XLSX::Reader::LibXML::Error - Moose class for remembering the last
     
 =head1 DESCRIPTION
 
-B<This documentation is written to explain ways to extend this package.  To use the data 
-extraction of Excel workbooks, worksheets, and cells please review the documentation for  
-L<Spreadsheet::XLSX::Reader::LibXML>,
-L<Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
-L<Spreadsheet::XLSX::Reader::LibXML::Cell>>
+This documentation is written to explain ways to use this module when writing your own excel 
+parser.  To use the general package for excel parsing out of the box please review the 
+documentation for L<Workbooks|Spreadsheet::XLSX::Reader::LibXML>,
+L<Worksheets|Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
+L<Cells|Spreadsheet::XLSX::Reader::LibXML::Cell>
 
 This L<Moose> class contains two L<attributes|Moose::Manual::Attributes>.  It is intended 
 to be used through (by) L<delegation|Moose::Manual::Delegation> in other classes.  The first 
 attribute is used to store the current error string.  The second, is set to turn on or off 
 pushing the error string to STDERR when the first attribute is (re)set.
 
-This class uses a role for full functional implementation.  Read the documentation 
-for each of the role(s) as well as this documentation to gain a complete picture of this 
-class.
-
-=head2 with
-
-These are attached role(s) for additional (re-used) functionality
-
-=head3 L<Spreadsheet::XLSX::Reader::LibXML::LogSpace>
-
 =head2 Attributes
 
 Data passed to new when creating an instance.   For modification of 
@@ -146,13 +136,12 @@ attributes see L<Moose::Manual::Attributes>.
 
 =over
 
-B<Definition:> This stores the most recent error string for recall later.  It 
-also provides a hook to debug logging through 
-L<Log::Shiras|https://github.com/jandrew/Log-Shiras>.
+B<Definition:> This stores an error string for recall later.
 
 B<Default> undef (init_arg = undef)
 
-B<Range> any string
+B<Range> any string (error objects with the 'as_string' or 'message' are auto coerced to 
+a string)
 
 B<attribute methods> Methods provided to adjust this attribute
 		
@@ -162,7 +151,7 @@ B<attribute methods> Methods provided to adjust this attribute
 
 =over
 
-B<Definition:> returns the currently stored error
+B<Definition:> returns the currently stored error string
 
 =back
 
@@ -170,7 +159,7 @@ B<Definition:> returns the currently stored error
 
 =over
 
-B<Definition:> clears the currently stored error
+B<Definition:> clears the currently stored error string
 
 =back
 
@@ -178,7 +167,7 @@ B<Definition:> clears the currently stored error
 
 =over
 
-B<Definition:> sets the attribute to $error_string.
+B<Definition:> sets the attribute with $error_string.
 
 =back
 
@@ -226,8 +215,8 @@ L<github Spreadsheet::XLSX::Reader::LibXML/issues
 
 =over
 
-B<1.> get clases in this package to return error numbers rather than 
-error strings and then provide opportunity for this class to localize.
+B<1.> get clases in this package to return error numbers and or error strings and 
+then provide opportunity for this class to localize.
 
 =back
 
@@ -235,9 +224,9 @@ error strings and then provide opportunity for this class to localize.
 
 =over
 
-=item Jed Lund
+Jed Lund
 
-=item jandrew@cpan.org
+jandrew@cpan.org
 
 =back
 
@@ -249,17 +238,17 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 by Jed Lund
+This software is copyrighted (c) 2014, 2015 by Jed Lund
 
 =head1 DEPENDENCIES
 
 =over
 
-L<version>
+L<version> - 0.77
 
 L<Moose>
 
-L<Carp>
+L<Carp> - cluck
 
 L<MooseX::StrictConstructor>
 
@@ -267,7 +256,7 @@ L<MooseX::HasDefaults::RO>
 
 L<Types::Standard>
 
-L<lib>
+L<Spreadsheet::XLSX::Reader::LibXML::Types> - v0.34
 
 =back
 
