@@ -2,12 +2,14 @@ package Spreadsheet::XLSX::Reader::LibXML::GetCell;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::GetCell::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.34.0');
+use version 0.77; our $VERSION = qv('v0.34.2');
 
 use	Moose::Role;
 requires qw(
 	min_row						max_row						min_col
 	max_col						row_range					col_range
+	_get_col_row				_get_next_value_cell		_get_row_all
+	
 );
 ###LogSD	requires 'get_log_space';
 use Types::Standard qw(
@@ -68,7 +70,7 @@ has custom_formats =>(
 		default => sub{ {} },
 		clearer	=> '_clear_custom_formats',
 	);
-
+#################################################
 has workbook_instance =>(
 		isa		=> HasMethods[qw(
 						counting_from_zero			boundary_flag_setting
@@ -80,6 +82,7 @@ has workbook_instance =>(
 						get_epoch_year				change_output_encoding
 						get_date_behavior			set_date_behavior
 						get_empty_return_type		set_error
+						get_values_only				set_values_only
 					)],
 		handles	=> [qw(
 						counting_from_zero			boundary_flag_setting
@@ -91,6 +94,7 @@ has workbook_instance =>(
 						get_epoch_year				change_output_encoding
 						get_date_behavior			set_date_behavior
 						get_empty_return_type		set_error
+						get_values_only				set_values_only
 					)],
 		required => 1,
 	);
@@ -157,17 +161,6 @@ sub fetchrow_arrayref{
 	###LogSD					name_space 	=> $self->get_log_space .  '::fetchrow_arrayref', );
 	###LogSD		$phone->talk( level => 'info', message =>[
 	###LogSD			"Arrived at fetchrow_arrayref for row: " . ((defined $row) ? $row : ''), ] );
-	if( !defined $row ){
-		my $last_col = $self->_get_reported_col;
-		###LogSD	$phone->talk( level => 'info', message =>[
-		###LogSD		"No row requested - Determining what it should be with the last column: $last_col", ] );
-		$row = $self->_get_reported_row + !!$last_col;
-		###LogSD	$phone->talk( level => 'info', message =>[
-		###LogSD		"Now requesting Excel row: $row", ] );
-		$row = $self->_get_used_position( $row );
-		###LogSD	$phone->talk( level => 'info', message =>[
-		###LogSD		"Which is used row: $row", ] );
-	}
 	
 	my $result = $self->get_row_all( $row );
 	###LogSD	$phone->talk( level => 'debug', message =>[ 'Returned row ref;', $result ] );
@@ -365,28 +358,34 @@ sub _build_out_the_cell{
 	my $return;
 	if( is_HashRef( $result ) ){
 		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Initial result is:", $result ] );
-		$result->{cell_type} = 'Text';
-		if( exists $result->{t} and $result->{t} eq 's' ){
-			@$result{qw( cell_unformatted rich_text )} =
-				@{$self->get_shared_string_position( $result->{v}->{raw_text} )}{qw( raw_text rich_text )};
-			delete $result->{t};
-			delete $result->{v};
-			delete $result->{rich_text} if !$result->{rich_text};
+		###LogSD		"processing cell object from cell ref:", $result ] );
+		$return->{cell_type} = 'Text';
+		$return->{r} = $result->{r};
+		$return->{cell_merge} = $result->{cell_merge} if exists $result->{cell_merge};
+		if( exists $result->{t} and $result->{t} eq 's' ){# Test for all in one sheet here!(future)
+			my $position = $self->get_shared_string_position( $result->{v}->{raw_text} );
+			###LogSD	$phone->talk( level => 'debug', message =>[
+			###LogSD		"Shared strings returned:",  $position] );
+			@$return{qw( cell_unformatted rich_text )} = ( $position->{raw_text}, $position->{rich_text} );
+			delete $return->{rich_text} if !$return->{rich_text};
+			###LogSD	$phone->talk( level => 'debug', message =>[
+			###LogSD		"Updated return:",  $return] );
 		}else{
-			$result->{cell_unformatted} = $result->{v}->{raw_text};
-			$result->{cell_type} = 'Numeric' if $result->{cell_unformatted} and $result->{cell_unformatted} ne '';
-			delete $result->{v};
+			###LogSD	$phone->talk( level => 'debug', message =>[
+			###LogSD		"Setting unformatted from:", $result ] );
+			$return->{cell_unformatted} = $result->{v}->{raw_text};
+			$return->{cell_type} = 'Numeric' if $return->{cell_unformatted} and $return->{cell_unformatted} ne '';
 		}
-		if( !$result->{cell_unformatted} and $self->get_empty_return_type eq 'empty_string' ){
+		if( !$return->{cell_unformatted} and $self->get_empty_return_type eq 'empty_string' ){
 			###LogSD	$phone->talk( level => 'debug', message =>[ "(Re)setting undef to ''"] );
-			$result->{cell_unformatted} = '';
+			$return->{cell_unformatted} = '';
 		}
 		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Cell raw text is:", $result->{cell_unformatted}] );
+		###LogSD		"Cell raw text is:", $return->{cell_unformatted}] );
 		if( $self->get_group_return_type eq 'unformatted' ){
-			my $reformatted = $self->change_output_encoding( $result->{cell_unformatted} );
-			return  $reformatted;
+			###LogSD	$phone->talk( level => 'debug', message =>[
+			###LogSD		"Sending back just the unformatted value: $return->{cell_unformatted}" ] ) ;
+			return $self->change_output_encoding( $return->{cell_unformatted} );
 		}
 		my	$custom_format;
 		if( $self->has_custom_format( $result->{r} ) ){
@@ -410,21 +409,24 @@ sub _build_out_the_cell{
 			###LogSD	$phone->talk( level => 'debug', message =>[
 			###LogSD		'Cell custom_format is:', $custom_format ] );
 			if( $self->get_group_return_type eq 'value' ){
-				my $reformatted = $self->change_output_encoding( $result->{cell_unformatted} );
+				my $reformatted = $self->change_output_encoding( $return->{cell_unformatted} );
+				###LogSD	$phone->talk( level => 'debug', message =>[
+				###LogSD		'Applying custom format to: ' .  $reformatted ] );
 				return $custom_format->assert_coerce( $reformatted );
 			}
 		}
 		# handle the formula
 		if( exists $result->{f} ){
-			$result->{cell_formula} = $result->{f}->{raw_text};
-			delete $result->{f};
+			$return->{cell_formula} = $result->{f}->{raw_text};
 		}
+		###LogSD	$phone->talk( level => 'debug', message =>[
+		###LogSD		"Cell args to this point:", $return] );
 		
 		if( exists $result->{s} ){
 			my $header = ($self->get_group_return_type eq 'value') ? 'numFmts' : undef;
 			my $format;
 			if( $self->_has_styles_file ){
-				$format = $self->get_format_position( $result->{s}, $header );#############  Change here when allow a list rather than a string filter
+				$format = $self->get_format_position( $result->{s}, $header );
 				###LogSD	$phone->talk( level => 'trace', message =>[
 				###LogSD		"format position is:", $format ] );
 			}
@@ -433,9 +435,9 @@ sub _build_out_the_cell{
 				###LogSD		"Attempting to just return the cell value with:",
 				###LogSD		((exists $format->{numFmts}) ? $format->{numFmts} : undef), ] );
 				if( exists $format->{numFmts} ){
-					return $format->{numFmts}->assert_coerce( $result->{cell_unformatted} );
+					return $format->{numFmts}->assert_coerce( $return->{cell_unformatted} );
 				}else{
-					return $result->{cell_unformatted};
+					return $return->{cell_unformatted};
 				}
 			}
 			if( $self->_has_styles_file ){
@@ -444,15 +446,15 @@ sub _build_out_the_cell{
 						###LogSD	$phone->talk( level => 'trace', message =>[
 						###LogSD		"Transferring styles header -$header- to cell attribute: $format_headers->{$header}", ] );
 						if( $header eq 'numFmts' ){
-							$result->{cell_coercion} = $format->{$header};
-							if(	$result->{cell_type} eq 'Numeric' and
+							$return->{cell_coercion} = $format->{$header};
+							if(	$return->{cell_type} eq 'Numeric' and
 								$format->{$header}->name =~ /date/i ){
 								###LogSD	$phone->talk( level => 'trace', message =>[
 								###LogSD		"Found a -Date- cell", ] );
-								$result->{cell_type} = 'Date';
+								$return->{cell_type} = 'Date';
 							}
 						}else{
-							$result->{$format_headers->{$header}} = $format->{$header};
+							$return->{$format_headers->{$header}} = $format->{$header};
 						}
 					}
 				}
@@ -460,56 +462,52 @@ sub _build_out_the_cell{
 			if( $custom_format ){
 				###LogSD	$phone->talk( level => 'trace', message =>[
 				###LogSD		"Using custom number formats", ] );
-				$result->{cell_coercion} = $custom_format;
-				$result->{cell_type} = 'Custom';
+				$return->{cell_coercion} = $custom_format;
+				$return->{cell_type} = 'Custom';
 			}
-			delete $result->{s},
 		}
 		###LogSD	$phone->talk( level => 'trace', message =>[
 		###LogSD		"Checking return type: " . $self->get_group_return_type ] );
 		if( $self->get_group_return_type eq 'value' ){
 			###LogSD	$phone->talk( level => 'trace', message =>[
 			###LogSD		"The caller only wants the coerced value (Not the whole cell)", ] );
-			if( !$result->{cell_coercion} ){
-				$result = $result->{cell_unformatted};
-			}elsif( !defined $result->{cell_unformatted} ){
-				$result = undef;
+			my $return_value;
+			if( !$return->{cell_coercion} ){
+				$return_value = $return->{cell_unformatted};
+			}elsif( !defined $return->{cell_unformatted} ){
 				$self->set_error( "The cell does not have a value" );
-				;
 			}else{
-				eval '$result = $result->{cell_coercion}->assert_coerce( $result->{cell_unformatted} )';
+				eval '$return_value = $return->{cell_coercion}->assert_coerce( $return->{cell_unformatted} )';
 				if( $@ ){
 					$self->set_error( $@ );
 				}
 			}
-			$result =~ s/\\//g if $result;
+			$return_value =~ s/\\//g if $return_value;
 			###LogSD	$phone->talk( level => 'trace', message =>[
-			###LogSD		"Returning: $result", ] );
-			return $result;
+			###LogSD		"Returning: $return_value", ] );
+			return $return_value;
 		}
-		$result->{cell_row} = $self->_get_used_position( $result->{row} );
-		delete $result->{row};
-		$result->{cell_col} = $self->_get_used_position( $result->{col} );
-		delete $result->{col};
-		$result->{error_inst} = $self->_get_error_inst;
-###LogSD	$result->{log_space} = $self->get_log_space . '::Cell';
-		$result->{unformatted_converter} = sub{ 
+		$return->{cell_row} = $self->_get_used_position( $result->{row} );
+		$return->{cell_col} = $self->_get_used_position( $result->{col} );
+		$return->{error_inst} = $self->_get_error_inst;
+		###LogSD	$result->{log_space} = $self->get_log_space . '::Cell';
+		$return->{unformatted_converter} = sub{ 
 			my	$string = $_[0];
 			###LogSD	$phone->talk( level => 'debug', message =>[
 			###LogSD		"Sending stuff to converter:", @_ ] );
 			$self->change_output_encoding( $string ) 
 		};
 		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Final ref is:", $result ] );
-		
-		# build cell
-		$return = Spreadsheet::XLSX::Reader::LibXML::Cell->new( %$result );
+		###LogSD		"Final args ref is:", $return] );
 	}elsif( $result ){
-		$return = ( $self->boundary_flag_setting ) ? $result : undef;
+		# This is where you return 'EOF' and 'EOR' flags
+		return ( $self->boundary_flag_setting ) ? $result : undef;
 	}
+	# build a cell
+	my $cell = Spreadsheet::XLSX::Reader::LibXML::Cell->new( %$return );
 	###LogSD		$phone->talk( level => 'debug', message =>[
-	###LogSD			"Cell is:", $return ] );
-	return $return;
+	###LogSD			"Cell is:", $cell ] );
+	return $cell;
 }
 
 # THE NEXT TWO METHODS ARE USED FOR ABSTRACTION AND DO NOT DO WHAT YOU THINK THEY DO
@@ -528,14 +526,21 @@ __END__
 =head1 NAME
 
 Spreadsheet::XLSX::Reader::LibXML::GetCell - Top level xlsx Worksheet interface
+
+=head1 SYNOPSIS
+
+If you are looking for the synopsis for the package see 
+L<Spreadsheet::XLSX::Reader::LibXML/SYNOPSIS>.  Otherwise the best example for use of 
+this module alone is the test file in this package 
+t/Spreadsheet/XLSX/Reader/LibXML/10-get_cell.t
     
 =head1 DESCRIPTION
 
-B<This documentation is written to explain ways to extend this package.  To use the data 
-extraction of Excel workbooks, worksheets, and cells please review the documentation for  
-L<Spreadsheet::XLSX::Reader::LibXML>,
-L<Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
-L<Spreadsheet::XLSX::Reader::LibXML::Cell>>
+This documentation is written to explain ways to use this module when writing your 
+own excel parser.  To use the general package for excel parsing out of the box please 
+review the documentation for L<Workbooks|Spreadsheet::XLSX::Reader::LibXML>,
+L<Worksheets|Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
+L<Cells|Spreadsheet::XLSX::Reader::LibXML::Cell>
 
 This is the extracted L<Role|Moose::Manual::Roles> to be used as a top level worksheet 
 interface.  This is the place where all the various details in each sub XML sheet are 
@@ -544,25 +549,25 @@ cell.  Since this is the center of data coallation all elements that may be cust
 should reside outside of this role.  This includes any specific elements that would be 
 different between each of the sheet parser types and any element of Excel data presentation 
 that may lend itself to customization.  For instance all the XML parser 
-methods, (Reader, DOM, and possibly SAX) can plug in outside of this role.
+methods, (Reader, DOM, and possibly SAX) should exist outside and preferebly below this 
+role.
 
-This role is also where a layer of abstraction is maintained to manage user defined 
-count-from-one or count-from-zero mode.  The layer of abstraction is use with the Moose 
-L<around|Moose::Manual::MethodModifiers/AROUND modifiers> modifier.  The behaviour is 
-managed with the workbook attribute L<counting_from_zero
-|Spreadsheet::XLSX::Reader::LibXML/count_from_zero>.
+This role is L<also|Spreadsheet::XLSX::Reader::LibXML::CellToColumnRow/DESCRIPTION> 
+contains a layer of abstraction to allow for run time setting of count-from-one or 
+count-from-zero mode.  The layer of abstraction is use with the Moose 
+L<around|Moose::Manual::MethodModifiers/AROUND modifiers> modifier.
 
 =head2 requires
 
 These are method(s) used by this Role but not provided by the role.  Any class consuming this 
 role will not build without first providing these methods prior to loading this role.  
-I<Since this is the center of data coallation the list is long>.
+I<Since this is the center of data collation the list is long>.
 
 =head3 min_row
 
 =over
 
-B<Definition:> Used to get the minimum data row set for the worksheet.
+B<Definition:> Used to get the minimum row with data in the worksheet.
 
 =back
 
@@ -570,7 +575,7 @@ B<Definition:> Used to get the minimum data row set for the worksheet.
 
 =over
 
-B<Definition:> Used to get the maximum data row set for the worksheet.
+B<Definition:> Used to get the maximum row with data in the worksheet.
 
 =back
 
@@ -578,7 +583,7 @@ B<Definition:> Used to get the maximum data row set for the worksheet.
 
 =over
 
-B<Definition:> Used to get the minimum data column set for the worksheet.
+B<Definition:> Used to get the minimum column with data in the worksheet.
 
 =back
 
@@ -586,7 +591,7 @@ B<Definition:> Used to get the minimum data column set for the worksheet.
 
 =over
 
-B<Definition:> Used to get the maximum data column set for the worksheet.
+B<Definition:> Used to get the maximum column with data in the worksheet.
 
 =back
 
@@ -594,7 +599,8 @@ B<Definition:> Used to get the maximum data column set for the worksheet.
 
 =over
 
-B<Definition:> Used to return a list of the $minimum_row and $maximum_row
+B<Definition:> Used to return a list of the L<$minimum_row|/min_row> and 
+L<$maximum_row|/max_row> values
 
 =back
 
@@ -602,41 +608,8 @@ B<Definition:> Used to return a list of the $minimum_row and $maximum_row
 
 =over
 
-B<Definition:> Used to return a list of the $minimum_column and $maximum_column
-
-=back
-
-=head3 change_output_encoding
-
-=over
-
-B<Definition:> This should be using the L<localization
-|Spreadsheet::XLSX::Reader::LibXML::FmtDefault/change_output_encoding> 
-role.  The role should be reachable by delegation through a workbook 
-parser attribute (trait) in the class consuming this role.
-
-=back
-
-=head3 get_group_return_type
-
-=over
-
-B<Definition:> This is where the L<group_return_type
-|Spreadsheet::XLSX::Reader::LibXML/group_return_type> attribute is used 
-as a consequence this role needs to understand the current setting.  It 
-should be reachable by delegation through a workbook parser attribute 
-(trait) in the class consuming this role.
-
-=back
-
-=head3 set_group_return_type
-
-=over
-
-B<Definition:> In order to speed up header reading and L<setting
-|/set_headers( @header_row_list )> the full cell is not needed, just the 
-value.  As a consequence this role changes the group_return_type attribute 
-as needed for header retrieval.
+B<Definition:> Used to return a list of the L<$minimum_column|/min_col> and 
+L<$maximum_column|/max_col> values.
 
 =back
 
@@ -648,23 +621,23 @@ B<Definition:> This should return the next cell data from the worksheet file
 that contains unique formatting or information.  The data is expected in a 
 perl hash ref.  This method should collect data left to right and top to 
 bottom.  I<The styles.xml, sharedStrings.xml, and calcChain.xml etc. sheet data 
-are coallated into the cell later in this role>.  An 'EOF' string should be 
+are coallated into the cell information at this point>.  An 'EOF' string should be 
 returned when the file has reached the end and then the method should wrap 
 back to the beginning.
 
-B<Example>
+B<Example of expected return data set>
 
-	{
-		'r' => 'A6',				# The cell ID
-		'cell_merge' => 'A6:B6',	# The merge range
-		'row' => 6,					# Already converted to count by 1
-		'col' => 1,					# Already converted to count by 1
-		't' => 's'					# Cell data type (string)
-		'v' => {					# Cell data (since this cell is string 
-			'raw_text' => '15'		# 	data this actually points to position 
-		}							# 	15 in the sharedStrings.xml file )
-		's' => '11',				# Styles type (position 11 in the styles sheet)
-	}
+   {
+      'r'          => 'A6',    # The cell ID
+      'cell_merge' => 'A6:B6', # The merge range
+      'row'        => 6,       # count by 1 (no 'around' performed on leading '_' methods)
+      'col'        => 1,       # count by 1 (no 'around' performed on leading '_' methods)
+      's'          => '11',    # Styles type (position 11 in the styles sheet)
+      't'          => 's'      # Cell data type (string)
+      'v' =>{                  # Cell data (since this cell is string 
+         'raw_text' => '15'    # data this actually points to position 
+      }                        #    15 in the sharedStrings.xml file )
+   }
 
 =back
 
@@ -673,11 +646,12 @@ B<Example>
 =over
 
 B<Definition:> Like L<_get_next_value_cell|/_get_next_value_cell> this method should 
-return the next cell.  The difference is it should return undef for empty cells rather 
-than skipping them.  This method should collect data left to right and top to bottom.  
-I<The styles.xml, sharedStrings.xml, and calcChain.xml etc. sheet data are coallated 
-into the cell later in this role>.  An 'EOF' string should be returned when the file 
-has reached the end and then the method should wrap back to the beginning.
+return the next cell.  The difference is it should return undef for empty cells 
+rather than skipping them.  This method should collect data left to right and top 
+to bottom.  I<The styles.xml, sharedStrings.xml, and calcChain.xml etc. sheet data 
+are coallated into the cell information at this point>.  An 'EOF' string should be 
+returned when the file has reached the end and then the method should wrap back to 
+the beginning.
 
 =back
 
@@ -685,173 +659,35 @@ has reached the end and then the method should wrap back to the beginning.
 
 =over
 
-B<Definition:> This method should provide a targeted way to return the worksheet file 
-information on a cell.  It should only accept count-from-one column and row numbers 
-and the column should be required before the row.  If the request is made for an out 
-of row bounds position the method should provide an 'EOR' string.  An 'EOF' string 
-should be returned when the file has reached the end and then the method should 
-wrap back to the beginning.
+B<Definition:> This method should provide a targeted way to return the worksheet 
+file information on a cell.  It should only accept count-from-one column and row 
+numbers and the column should be required before the row.  If the request is made 
+for an out of row bounds position the method should provide an 'EOR' string.  An 
+'EOF' string should be returned when the file has reached the end and then the 
+method should wrap back to the beginning.
 
 =back
 
-=head3 _get_error_inst
-
-=over
-
-B<Definition:> This method is used to access the shared 
-L<Spreadsheet::XLSX::Reader::LibXML/error_inst>
-
-=back
-
-=head3 counting_from_zero
-
-=over
-
-B<Definition:> This role implements some of the L<count_from_zero
-|Spreadsheet::XLSX::Reader::LibXML/count_from_zero> attribute behaviors so it needs to 
-be able to read the current state.
-
-=back
-
-=head3 boundary_flag_setting
-
-=over
-
-B<Definition:> This role implements some of the L<file_boundary_flags
-|Spreadsheet::XLSX::Reader::LibXML/file_boundary_flags> attribute behaviors so it needs to 
-be able to read the current state.
-
-=back
-
-=head3 _has_shared_strings_file
-
-=over
-
-B<Definition:> This should indicate if the sharedStrings.xml file is available
-
-=back
-
-=head3 get_shared_string_position( $position )
-
-=over
-
-B<Definition:> This should return a hashref of data for the indicated $position
-
-B<Example:>  from the example shared strings position 15
-
-	{
-		'rich_text' => [				# Rich text definition
-			2,							# Position from 0 to start this element
-			{							# Element definition
-				'color' => {
-					'rgb' => 'FFFF0000'
-				},
-				'sz' => '11',
-				'b' => 1,
-				'scheme' => 'minor',
-				'rFont' => 'Calibri',
-				'family' => '2'
-			},
-			6,							# Position from 0 to start this element
-			{							# Element definition
-				'color' => {
-					'rgb' => 'FF0070C0'
-				},
-				'sz' => '20',
-				'b' => 1,
-				'scheme' => 'minor',
-				'rFont' => 'Calibri',
-				'family' => '2'
-			}
-			],
-		'raw_text' => 'Hello World',	# The raw text the format is applied to
-	}
-
-=back
-
-=head3 _has_styles_file
-
-=over
-
-B<Definition:> This should indicate if the styles.xml file is available
-
-=back
-
-=head3 get_format_position( $position )
-
-=over
-
-B<Definition:> This should return a hashref of data for the indicated $position 
-in the styles.xml file.  This will include any general cell formatting as well as 
-any references to the subroutines for number conversions either defined by Excel or
-any custom (user defined) conversion subroutines
-
-B<Example:>  from the example styles position 11
-
-	{
-		'fontId' => '0',
-		'fonts' => {
-			'color' => {
-				'theme' => '1'
-			},
-			'sz' => '11',
-			'name' => 'Calibri',
-			'scheme' => 'minor',
-			'family' => '2'
-		},
-		'numFmtId' => '0',
-		'fillId' => '0',
-		'xfId' => '0',
-		'applyAlignment' => '1',
-		'borders' => {
-			'left' => 1,
-			'right' => 1,
-			'top' => 1,
-			'diagonal' => 1,
-			'bottom' => 1
-		},
-		'borderId' => '0',
-		'alignment' => {
-			'horizontal' => 'left'
-		},
-		'cellStyleXfs' => {
-			'fillId' => '0',
-			'fontId' => '0',
-			'borderId' => '0',
-			'numFmtId' => '0'
-		},
-		'fills' => {
-			'patternFill' => {
-				'patternType' => 'none'
-			}
-		},
-		'numFmts' => bless( {						# This is the package build Type::Tiny object
-			'name' => 'Excel_number_0',				#  to be use for coercion
-			'coercion' => bless( { 
-				~~ Type::Coercion instance here ~~
-			 }, 'Type::Coercion' ),
-		'display_name' => 'Excel_number_0',
-		'uniq' => 94
-		}, 'Type::Tiny' )
-	}
-
-=back
+I<The attribute L<workbook_instance|/workbook_instance> must also be filled 
+correctly since it exports all of the the workbook level functionality to this class.> 
 
 =head2 Primary Methods
 
-These are the various methods provided by this role.
+These are the various methods provided by this role.  Each of them calls a sub method 
+to get the base cell data and then coallates that information into the proper return 
+value(s) defined by L<Spreadsheet::XLSX::Reader::LibXML/group_return_type>.
 
 =head3 get_cell( $row, $column )
 
 =over
 
-B<Definition:> Used to return the cell or information from the cell at the 
-specified $row and $column.  Both $row and $column are required.
+B<Definition:> This calls the supplied method L<_get_col_row|/_get_col_row>.
 
-B<Accepts:> the list ( $row, $column ) both required
+B<Accepts:> the list ( $row, $column ) both required (and modified as needed by the 
+attribute state of L<Spreadsheet::XLSX::Reader::LibXML/count_from_zero>)
 
-B<Returns:> see L<group_return_type|Spreadsheet::XLSX::Reader::LibXML/group_return_type> 
-for details on what is returned
+B<Returns:> if data to build a cell instance is provided then the instance is collated, 
+built, and returned.  Otherwise the value from '_get_col_row' is returned unfiltered.
 
 =back
 
@@ -859,14 +695,13 @@ for details on what is returned
 
 =over
 
-B<Definition:> Reading left to right and top to bottom this will return the next cell with 
-a value.  This actually includes cells with no value but some unique formatting such as 
-cells that have been merged with other cells.
+B<Definition:> This calls the supplied method L<_get_next_value_cell|/_get_next_value_cell>
 
 B<Accepts:> nothing
 
-B<Returns:> see L<group_return_type|Spreadsheet::XLSX::Reader::LibXML/group_return_type> 
-for details on what is returned
+B<Returns:> if data to build a cell instance is provided then the instance is collated, 
+built, and returned.  Otherwise the value from '_get_next_value_cell' is returned 
+unfiltered.
 
 =back
 
@@ -874,14 +709,15 @@ for details on what is returned
 
 =over
 
-B<Definition:> In an homage to L<DBI> I included this function to return an array ref of 
-the cells or values in the requested $row.  If no row is requested this returns the 'next' 
-row.  In the array ref any empty and non unique cell will show as 'undef'.
+B<Definition:>  This calls the supplied method L<_get_row_all|/_get_row_all>.  It will 
+return 'EOF' once instead of an array reference for the end of the file before resetting 
+to the first row..
 
-B<Accepts:> undef = next|$row = a row integer indicating the desired row
+B<Accepts:> undef = next|$row = a row integer indicating the desired row (modified as 
+needed by the attribute state of L<Spreadsheet::XLSX::Reader::LibXML/count_from_zero>)
 
 B<Returns:> an array ref of all possible column positions in that row with data filled in 
-as appropriate.
+as appropriate. (or 'EOF')
 
 =back
 
@@ -889,7 +725,7 @@ as appropriate.
 
 =over
 
-B<Definition:> This function is just like L<fetchrow_arrayref|/fetchrow_arrayref( $row )> 
+B<Definition:> This function calls L<fetchrow_arrayref|/fetchrow_arrayref( $row )> 
 except it returns an array instead of an array ref
 
 B<Accepts:> undef = next|$row = a row integer indicating the desired row
@@ -913,7 +749,8 @@ while setting the error instance.  If some of the columns do not have values the
 the instance will auto generate unique headers for each empty header column to fill 
 out the header ref.
 
-B<Accepts:> a list of row numbers
+B<Accepts:> a list of row numbers (modified as needed by the attribute state of 
+L<Spreadsheet::XLSX::Reader::LibXML/count_from_zero>)
 
 B<Returns:> an array ref of the built headers for review
 
@@ -925,8 +762,9 @@ B<Returns:> an array ref of the built headers for review
 
 B<Definition:> This function is used to return a hashref representing the data in the 
 specified row.  If no $row value is passed it will return the 'next' row of data.  A call 
-to this function without L<setting|/( @header_row_list )> the headers first 
-will return undef and set the error instance.
+to this function without L<setting|/set_headers( @header_row_list )> the headers first 
+will return undef and set the error instance.  This function calls 
+L<_get_row_all|/_get_row_all>.
 
 B<Accepts:> a target $row number for return values or undef meaning 'next'
 
@@ -936,20 +774,20 @@ B<Returns:> a hash ref of the values for that row
 
 =head2 Attributes
 
-Data passed to new when creating the L<Styles|Spreadsheet::XLSX::Reader::LibXML::Worksheet> 
-instance.   For modification of these attributes see the listed 'attribute methods'.
-For more information on attributes see L<Moose::Manual::Attributes>.  Most of these are 
-not exposed to the top level of the workbook L<parser|Spreadsheet::XLSX::Reader::LibXML>.  
-As a consequence these attribute methods which are available at the worksheet instance 
-level are the best way to manipulate the attribute settings.
+Arguments that can be passed to new when creating a class instance or changed using 
+one of the 'attribute methods'.   Where an attribute is delegating the 'attribute 
+method' from a method in the instance stored in the attribute the documentation will 
+indicate that the 'attribute method' is 'delegated'.  I<All 'delegated' methods are 
+required for the instance to be accepted by the attribute.>  For more information on 
+attributes see L<Moose::Manual::Attributes> and L<Moose::Manual::Delegation>.
 
 =head3 last_header_row
 
 =over
 
-B<Definition:> This is generally set by the method L<set_headers
-|/set_headers( @header_row_list )> and is the largest row number of the @header_row_list 
-even if the list is out of sequence.
+B<Definition:> This is generally set by the method L<set_headers( @header_row_list )
+|/set_headers( @header_row_list )> method I<not during -E<gt>new> and is the largest row number 
+of the @header_row_list I<not necessarily the last number in the sequence>.
 
 B<Default:> undef
 
@@ -981,10 +819,9 @@ B<Definition:> predicate for the attribute
 
 =over
 
-B<Definition:> When the method L<fetchrow_array(ref)|/fetchrow_arrayref( $row )> 
-or L<fetchrow_hashref|/fetchrow_hashref( $row )> are called it is possible to 
-only collect a set of information between two defined columns.  This is the 
-attribute that defines the start point.
+B<Definition:> When the method L<fetchrow_hashref|/fetchrow_hashref( $row )> is 
+called it is possible to only return a set of information between two defined 
+columns.  This is the attribute that defines the start column.
 
 B<Default:> undef
 
@@ -996,7 +833,10 @@ B<set_min_header_col>
 
 =over
 
-B<Definition:> returns the value of the attribute
+B<Definition:> sets the value of the attribute
+
+B<Range:> integer values I<Integers less than L<min_col|/min_col> will 
+be ignored>
 
 =back
 		
@@ -1022,7 +862,7 @@ B<clear_min_header_col>
 
 =over
 
-B<Definition:> sets min_header_col to undef
+B<Definition:> sets min_header_col to 'undef'
 
 =back
 
@@ -1036,10 +876,9 @@ B<Definition:> sets min_header_col to undef
 
 =over
 
-B<Definition:> When the method L<fetchrow_array(ref)|/fetchrow_arrayref( $row )> 
-or L<fetchrow_hashref|/fetchrow_hashref( $row )> are called it is possible to 
-only collect a set of information between two defined columns.  This is the 
-attribute that defines the end point.
+B<Definition:> When the method L<fetchrow_hashref|/fetchrow_hashref( $row )> 
+is called it is possible to only collect a set of information between two defined 
+columns.  This is the attribute that defines the end column.
 
 B<Default:> undef
 
@@ -1051,7 +890,10 @@ B<set_max_header_col>
 
 =over
 
-B<Definition:> returns the value of the attribute
+B<Definition:> sets the value of the attribute
+
+B<Range:> integer values I<Integers larger than L<max_col|/max_col> will 
+be ignored>
 
 =back
 		
@@ -1077,7 +919,7 @@ B<clear_max_header_col>
 
 =over
 
-B<Definition:> sets min_header_col to undef
+B<Definition:> sets min_header_col to 'undef'
 
 =back
 
@@ -1095,9 +937,13 @@ B<Definition:> When this role is coallating data about a cell it will check this
 attribute before it checks the styles sheet to see if there is a format defined 
 by the user for converting the L<unformatted
 |Spreadsheet::XLSX::Reader::LibXML::Cell/unformatted> data.  The formats stored 
-must have two methods 'assert_coerce' and 'display_name'.  The collater first 
-checks the cellID as a key, then it checks for just the column letter(s) as a key, 
-and finally it checks the row number as a key.
+must have two methods 'assert_coerce' and 'display_name'.  The cell instance 
+builder will consult this attribute by first checking the cellID as a key, then 
+it checks for just the column letter(s) as a key, and finally it checks the row 
+number as a key.  For an easy way to build custom conversion review the 
+documentation for L<Type::Tiny|Type::Tiny::Manual::Libraries> and 
+L<Type::Coercions|Type::Tiny::Manual::Coercions>. I<the Chained Coercions are 
+very cool!.>
 
 B<Default:> undef
 
@@ -1105,7 +951,7 @@ B<attribute methods> Methods provided to adjust this attribute
 		
 =over
 
-B<set_custom_formats( { $key => $conversion } )>
+B<set_custom_formats( { $key =E<gt> $conversion } )>
 
 =over
 
@@ -1135,7 +981,7 @@ B<Returns:> the $conversion registered to the $key
 
 =back
 
-B<set_custom_format( $key => $conversion )>
+B<set_custom_format( $key =E<gt> $conversion )>
 
 =over
 
@@ -1149,6 +995,70 @@ B<Definition:> set the custom format $conversion for the identified $key
 
 =back
 
+=head3 workbook_instance
+
+=over
+
+B<Definition:> This is where the workbook level methods are accessed by 
+the worksheet.  Because the workbook class is complex and I don't wan't to 
+maintain duplicate documentation I request that you review the 
+L<documentation|Spreadsheet::XLSX::Reader::LibXML> for that class 
+there.  This attribute can/should only be set at ->new, however, it 
+delegates to this class a number of methods that will update the workbook 
+instance and therefore have universal effect when the other sheets are read.
+
+B<Default:> none
+
+B<Required:> yes
+
+B<attribute methods> Methods provided to adjust this attribute
+		
+=over
+
+B<counting_from_zero> - delegated
+
+B<boundary_flag_setting> - delegated
+
+B<change_boundary_flag> - delegated
+
+B<_has_shared_strings_file> - delegated
+
+B<get_shared_string_position> - delegated
+
+B<_has_styles_file> - delegated
+
+B<get_format_position> - delegated
+
+B<set_empty_is_end> - delegated
+
+B<is_empty_the_end> - delegated
+
+B<_starts_at_the_edge> - delegated
+
+B<get_group_return_type> - delegated
+
+B<set_group_return_type> - delegated
+
+B<get_epoch_year> - delegated
+
+B<change_output_encoding> - delegated
+
+B<get_date_behavior> - delegated
+
+B<set_date_behavior> - delegated
+
+B<get_empty_return_type> - delegated
+
+B<set_error> - delegated
+
+B<set_values_only> - delegated
+
+B<get_values_only> - delegated
+
+=back
+
+=back
+
 =head1 SUPPORT
 
 =over
@@ -1187,13 +1097,47 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 by Jed Lund
+This software is copyrighted (c) 2014, 2015 by Jed Lund
 
 =head1 DEPENDENCIES
 
 =over
 
-L<Spreadsheet::XLSX::Reader::LibXML>
+L<version> - 0.77
+
+L<Type::Tiny> - 1.000
+
+L<Spreadsheet::XLSX::Reader::LibXML::Cell>
+
+L<Moose::Role>
+
+=over
+
+B<requires>
+
+=over
+
+min_row
+
+max_row
+
+min_col
+
+max_col
+
+row_range
+
+col_range
+
+_get_col_row
+
+_get_next_value_cell
+
+_get_row_all
+
+=back
+
+=back
 
 =back
 
