@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.34.0');
+use version; our $VERSION = qv('v0.34.2');
 
 
 use	5.010;
@@ -204,10 +204,13 @@ sub _load_unique_bits{
 		my	$range = $self->get_attribute( 'ref' );
 		my	( $start, $end ) = split( /:/, $range );
 		###LogSD	$phone->talk( level => 'debug', message => [
-		###LogSD		"Start position: $start", "End position: $end", "Byte position: " . $self->byte_consumed ] );
+		###LogSD		"Start position: $start", 
+		###LogSD		( $end ? "End position: $end" : '' ), "Byte position: " . $self->byte_consumed ] );
 		my ( $start_column, $start_row ) = ( $self->_starts_at_the_edge ) ?
 												( 1, 1 ) : $self->_parse_column_row( $start );
-		my ( $end_column, $end_row	) = $self->_parse_column_row( $end );
+		my ( $end_column, $end_row	) = $end ? 
+				$self->_parse_column_row( $end ) : 
+				( $start_column, $start_row ) ;
 		###LogSD	$phone->talk( level => 'debug', message => [
 		###LogSD		"Start column: $start_column", "Start row: $start_row",
 		###LogSD		"End column: $end_column", "End row: $end_row" ] );
@@ -268,10 +271,26 @@ sub _get_next_value_cell{
 		###LogSD			'Reached the end of the file',] );
 		$self->start_the_file_over;
 	}else{
-		$sub_ref = $self->parse_element;
-		@$sub_ref{qw( col row )} = $self->_parse_column_row( $sub_ref->{r} );
-		###LogSD	$phone->talk( level => 'trace', message => [
-		###LogSD		'The next cell with data is:', $sub_ref,] );
+		$sub_ref = undef;
+		CHECKVALUECELLS: while( !$sub_ref or $self->get_values_only ){
+			$sub_ref = $self->parse_element;
+			@$sub_ref{qw( col row )} = $self->_parse_column_row( $sub_ref->{r} );
+			###LogSD	$phone->talk( level => 'trace', message => [
+			###LogSD		'The next cell with data is:', $sub_ref,] );
+			if( exists $sub_ref->{v} or !$self->get_values_only ){### Other text or value call outs here?
+				###LogSD	$phone->talk( level => 'trace', message => [
+				###LogSD		'Found a cell with a value no additional work is needed' ,] );
+				last CHECKVALUECELLS;
+			}
+			$result = $self->next_element( 'c' ) if !$self->node_name or $self->node_name ne 'c';
+			if( !$result ){
+				###LogSD	$phone->talk( level => 'debug', message => [
+				###LogSD			'Reached the end of the file',] );
+				$sub_ref = 'EOF';
+				$self->start_the_file_over;
+				last CHECKVALUECELLS;
+			}
+		}
 	}
 	
 	#Add merge value
@@ -493,10 +512,15 @@ sub _get_row_all{
 	###LogSD					name_space 	=> ($self->get_log_space . '::_get_row_all' ), );
 	###LogSD		$phone->talk( level => 'debug', message => [
 	###LogSD			'Getting row: ' . (($row) ? $row : undef) ] );
-	# Validate
+	
+	# Get next row as needed
 	if( !$row ){
-		$self->set_error( "Need to pass a row number - non passed" );
-		return undef;
+		my $last_col = $self->_get_reported_col;
+		###LogSD	$phone->talk( level => 'info', message =>[
+		###LogSD		"No row requested - Determining what it should be with the last column: $last_col", ] );
+		$row = $self->_get_reported_row + !!$last_col;
+		###LogSD	$phone->talk( level => 'info', message =>[
+		###LogSD		"Now requesting Excel row: $row", ] );
 	}
 	
 	# See if you went too far
